## LinksReferrer :
    - generate shortlinks for free
    
## usage: 

``` 
from links_referrer import LinksReferrer
Referral = LinksReferrer(url="https://youtu.be/ubVJ8OARMxs")
print(Referral.getshortcuts())

```
